@@ -6,8 +6,8 @@ use crate::file::overwrite_check;
 use crate::file::write_bytes_to_file;
 use crate::hashing::hash_data_blake3;
 
+use crate::global::DexiosFile;
 use crate::prompt::get_answer;
-use crate::structs::DexiosFile;
 use anyhow::{Context, Ok, Result};
 use std::fs::File;
 
@@ -62,7 +62,7 @@ pub fn decrypt_file(
     let raw_key = get_user_key(keyfile)?;
 
     println!(
-        "Decrypting {} in normal mode (this may take a while)",
+        "Decrypting {} in legacy mode (this may take a while)",
         input
     );
     let decrypt_start_time = Instant::now();
@@ -91,6 +91,7 @@ pub fn decrypt_file_stream(
     input: &str,
     output: &str,
     keyfile: &str,
+    hash_mode: bool,
     skip: bool,
     bench: bool,
 ) -> Result<()> {
@@ -108,7 +109,7 @@ pub fn decrypt_file_stream(
         input
     );
     let decrypt_start_time = Instant::now();
-    decrypt_bytes_stream(&mut input_file, &mut output_file, raw_key, bench)?;
+    decrypt_bytes_stream(&mut input_file, &mut output_file, raw_key, bench, hash_mode)?;
     let decrypt_duration = decrypt_start_time.elapsed();
     println!(
         "Decryption successful! [took {:.2}s]",
