@@ -27,7 +27,7 @@ pub fn get_user_key(keyfile: &str) -> Result<Vec<u8>> {
             .context("Unable to read DEXIOS_KEY from environment variable")?
             .into_bytes()
     } else {
-        println!("Reading key from stdin");
+        println!("Reading key from the terminal");
         get_password_with_validation()?
     })
 }
