@@ -5,13 +5,13 @@ mod decrypt;
 mod encrypt;
 mod erase;
 mod file;
+mod global;
 mod hashing;
 mod prompt;
-mod structs;
 
 fn main() -> Result<()> {
     let matches = Command::new("dexios")
-        .version("6.3.6")
+        .version(clap::crate_version!())
         .author("brxken128 <github.com/brxken128>")
         .about("Secure command-line encryption of files.")
         .subcommand_required(true)
@@ -73,7 +73,14 @@ fn main() -> Result<()> {
                         .short('s')
                         .long("stream")
                         .takes_value(false)
-                        .help("use stream encryption (ideal for large files)"),
+                        .help("use stream encryption - default"),
+                )
+                .arg(
+                    Arg::new("legacy")
+                        .short('l')
+                        .long("legacy")
+                        .takes_value(false)
+                        .help("load the file into memory before encrypting"),
                 ),
         )
         .subcommand(
@@ -134,7 +141,14 @@ fn main() -> Result<()> {
                         .short('s')
                         .long("stream")
                         .takes_value(false)
-                        .help("use stream decryption (ideal for large files)"),
+                        .help("use stream decryption - default"),
+                )
+                .arg(
+                    Arg::new("legacy")
+                        .short('l')
+                        .long("legacy")
+                        .takes_value(false)
+                        .help("load the file into memory before encrypting"),
                 ),
         )
         .get_matches();
@@ -148,9 +162,8 @@ fn main() -> Result<()> {
                     .context("No keyfile/invalid text provided")?;
             }
 
-            let result = if sub_matches.is_present("stream") {
-                // if we're streaming or not
-                encrypt::encrypt_file_stream(
+            let result = if sub_matches.is_present("legacy") {
+                encrypt::encrypt_file(
                     sub_matches
                         .value_of("input")
                         .context("No input file/invalid text provided")?,
@@ -158,11 +171,12 @@ fn main() -> Result<()> {
                         .value_of("output")
                         .context("No output file/invalid text provided")?,
                     keyfile,
+                    sub_matches.is_present("hash"),
                     sub_matches.is_present("skip"),
                     sub_matches.is_present("bench"),
                 )
             } else {
-                encrypt::encrypt_file(
+                encrypt::encrypt_file_stream(
                     sub_matches
                         .value_of("input")
                         .context("No input file/invalid text provided")?,
@@ -192,8 +206,8 @@ fn main() -> Result<()> {
                     .context("No keyfile/invalid text provided")?;
             }
 
-            let result = if sub_matches.is_present("stream") {
-                decrypt::decrypt_file_stream(
+            let result = if sub_matches.is_present("legacy") {
+                decrypt::decrypt_file(
                     sub_matches
                         .value_of("input")
                         .context("No input file/invalid text provided")?,
@@ -201,11 +215,12 @@ fn main() -> Result<()> {
                         .value_of("output")
                         .context("No output file/invalid text provided")?,
                     keyfile,
+                    sub_matches.is_present("hash"),
                     sub_matches.is_present("skip"),
                     sub_matches.is_present("bench"),
                 )
             } else {
-                decrypt::decrypt_file(
+                decrypt::decrypt_file_stream(
                     sub_matches
                         .value_of("input")
                         .context("No input file/invalid text provided")?,
