@@ -28,7 +28,7 @@ pub fn get_answer(prompt: &str, default: bool, skip: bool) -> Result<bool> {
             'y' => true,
             'n' => false,
             _ => {
-                println!("Incorrect value submitted, please try again");
+                println!("Unrecognised answer - please try again");
                 continue;
             }
         };
